#!/usr/bin/env python
from setuptools import setup
setup(
  name = 'cs.asynchron',
  description = 'Result and friends: callable objects which will receive a value at a later point in time.',
  author = 'Cameron Simpson',
  author_email = 'cs@zip.com.au',
  version = '20160828',
  url = 'https://bitbucket.org/cameron_simpson/css/commits/all',
  classifiers = ['Programming Language :: Python', 'Programming Language :: Python :: 2', 'Programming Language :: Python :: 3', 'License :: OSI Approved :: GNU General Public License v3 (GPLv3)', 'Development Status :: 4 - Beta', 'Topic :: Software Development :: Libraries :: Python Modules', 'Intended Audience :: Developers', 'Operating System :: OS Independent'],
  install_requires = ['cs.obj', 'cs.seq', 'cs.py3'],
  keywords = ['python2', 'python3'],
  long_description = 'Asynchron and friends.\n----------------------\n\nAn Asynchron is the base class for several callable subclasses which will receive values at a later point in time, and can also be used standalone without subclassing.\n\nA call to an Asynchron will block until the value is received or the Asynchron is cancelled, which will raise an exception in the caller.\nAn Asynchron may be called by multiple users, before or after the value has been delivered; if the value has been delivered the caller returns with it immediately.\nAn Asynchron\'s state may be inspected (pending, running, ready, cancelled).\nCallbacks can be registered via an Asychron\'s .notify method.\n\nAn incomplete Asynchron can be told to call a function to compute its value; the function return will be stored as the value unless the function raises an exception, in which case the exception information is recorded instead. If an exception occurred, it will be reraised for any caller of the Asynchron.\n\nTrite example::\n\n  A = Asynchron(name="my demo")\n\n  Thread 1:\n    value = A()\n    # blocks...\n    print(value)\n    # prints 3 once Thread 2 (below) assigns to it\n\n  Thread 2:\n    A.result = 3\n\n  Thread 3:\n    value = A()\n    # returns immediately with 3\n\nYou can also collect multiple Asynchrons in completion order using the report() function::\n\n  As = [ ... list of Asynchrons or whatever type ... ]\n  ...\n  for A in report(As):\n    x = A()     # collect result, will return immediately\n    print(x)    # print result\n',
  package_dir = {'': 'lib/python'},
  py_modules = ['cs.asynchron'],
)
